| Title: | Binaries for Tools Used in Genetics in an R Package |
|---|---|
| Description: | A convenient way to make binaries such as plink, bcftools, and others available to other packages. This package forms part of the MRC IEU OpenGWAS system. The system includes other R packages, including; gwasglue, ieugwasr, gwasvcf, and TwoSampleMR. |
| Authors: | Gibran Hemani [aut, cre] (ORCID: <https://orcid.org/0000-0003-0920-1055>), Tom Palmer [aut] (ORCID: <https://orcid.org/0000-0003-4655-4511>) |
| Maintainer: | Gibran Hemani <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.2 |
| Built: | 2026-05-22 06:50:54 UTC |
| Source: | https://github.com/MRCIEU/genetics.binaRies |
Find binary for bcftools
get_bcftools_binary()get_bcftools_binary()
Path to bcftools
if (Sys.info()[["sysname"]] != "Windows") get_bcftools_binary()if (Sys.info()[["sysname"]] != "Windows") get_bcftools_binary()
Find binary for gcta
get_gcta_binary()get_gcta_binary()
path to gcta
get_gcta_binary()get_gcta_binary()
Find binary for plink
get_plink_binary()get_plink_binary()
Path to plink
get_plink_binary()get_plink_binary()